﻿Fluke Calibration                                           MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Level Signal /4419,8481,8482,SWPG
DATE:                  2012-06-26 11:31:55
AUTHOR:                Fluke Calibration
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       141
CONFIGURATION:         Agilent E4419B
CONFIGURATION:         HP 8481A on channel 1
CONFIGURATION:         HP 8482A on channel 2
=============================================================================
#
#  Procedure Author:
#        DFM
#
#  Model(s) Covered:
#        General purpose use, wherever an externally leveled (RF) signal,
#        >=10 MHz and <=18 GHz (Channel A), and >=100 kHz and <=4.2 GHz,
#        (Channel B), using an SWPG, and one or both channels having 8481A
#        and 8482A sensors, as required.
#
#  Compatibility:
#        MET/CAL 7.3 SP1 (7.3.36) or later
#
#  Subprocedures:
#        Sub Apply /SWPG
#
#  Required Files:
#        None
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The necessary parameters for this procedure are passed from the calling
#  procedure.
#
#  @TestName   : The test being performed when this sub is being called.
#  @CenterFreq : The desired Sweep Generator output frequency.
#  @RefLvl     : The desired reference level as measured by the power meter.
#  @TestLvl    : The Sweep Generator output level required to generate the
#                specified reference level.
#  @HiLimit    : The upper limit of the setting aperture (in dBm).
#  @LoLimit    : The lower limit of the setting aperture (in dBm).
#  @Error      : Flag to indicate success or failure of leveling process and
#                facilitating 'bail-out' in the case of the latter.
#
#  Example:
# 1.001  M4419  F32   8481A          Default       8482A          100pct
# 1.002  MATH         @TestName = "Frequency Response"; @Chan = 2
# 1.003  MATH         @CenterFreq = "350 MHz"; @RefLvl = -12; @TestLvl = -12
# 1.004  MATH         @LoLimit = -12.05; @HiLimit = -11.95
# 1.005  CALL         Sub Level Signal /4419,8481,8482,SWPG
#
# 1.006  IF           @Error
# 1.007  EVAL   -e 0 : An error occurred during the [V @TestName] test.
# 2.001  MATH         @Error = 0
# 2.002  END
# 2.003  ENDIF
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  IF           0
# M4419 statement to allow procedure to compile.
  1.002  M4419  F64   8481A          "HP8481A"     8482A          Default
  1.003  IEEE         [@SWPG]
  1.004  ENDIF

# Pass center frequency (in Hz) from calling procedure to power meter.
  1.005  MATH         MEM = @CenterFreq

  1.006  IF           ISVAR("@Chan")

  1.007  IF           ZCMPI(@Chan, "A")
  1.008  4419         -25.00D                      H                 RF N  CH1
  1.009  ELSEIF       ZCMPI(@Chan, "B")
  1.010  4419         -25.00D                      H                 RF N  CH2
  1.011  ENDIF

  1.012  ELSE

  1.013  4419         -25.00D                      H                 RF N  CH1
  1.014  ENDIF

  1.015  WHILE        ((MEM <= @LoLimit) || (MEM >= @HiLimit)) && NOT(@Error)
  1.016  MATH         Delta = (@RefLvl - MEM)
  1.017  MATH         @TestLvl = @TestLvl + Delta

  1.018  IF           (@TestLvl < -100) || (@TestLvl > 20)
  1.019  OPBR         -z Error: Unable to adjust the Sweep Generator output
  1.019  OPBR         [32]      level within its operating range to achieve
  1.019  OPBR         [32]      the desired test level ([V @RefLvl] dBm).
  1.019  OPBR
  1.019  OPBR         [32]      Verify UUT test requirements, SWPG output
  1.019  OPBR         [32]      limits, and connections prior to retrying,
  1.019  OPBR         [32]      if desired.
  1.019  OPBR
  1.019  OPBR         Do you wish to RETRY?
  1.019  OPBR
  1.019  OPBR         (Selecting "No" will cause the [V @TestName] test
  1.019  OPBR         to be terminated.)

  1.020  IF           MEM1
  1.021  MATH         @TestLvl = @RefLvl
  1.022  ELSE
  1.023  MATH         @Error = 1
  1.024  END
  1.025  ENDIF

  1.026  ENDIF

  1.027  MATH         @SWPG_Ampl = @TestLvl & "dBm"
  1.028  CALL         Sub Apply /SWPG
  1.029  MATH         MEM = @CenterFreq

  1.030  IF           ISVAR("@Chan")

  1.031  IF           ZCMPI(@Chan, "A")
  1.032  4419         -25.00D                      H                 RF N  CH1
  1.033  ELSEIF       ZCMPI(@Chan, "B")
  1.034  4419         -25.00D                      H                 RF N  CH2
  1.035  ENDIF

  1.036  ELSE

  1.037  4419         -25.00D                      H                 RF N  CH1
  1.038  ENDIF

  1.039  ENDW

  1.040  END
